@@ -14,6 +14,8 @@ rm -rf \
 	libtool \
 	ltconfig \
 	ltmain.sh \
+	m4/lt*.m4 \
+	m4/libtool.m4 \
 	Makefile \
 	Makefile.in \
 	missing \
@@ -35,7 +37,7 @@ rm -rf \
 	examples/Makefile.in \
 	test/Makefile.in \
 	test/*/Makefile.in \
-	test/protocol/tests/Makefile.in \
+	test/*/*/Makefile.in \
 	pkgconfig/Makefile \
 	pkgconfig/Makefile.in \
 	pkgconfig/libgadu.pc \
