@@ -162,7 +162,7 @@ void gg_debug_session(struct gg_session *gs, int level, const char *format, ...)
 void gg_debug_dump(struct gg_session *gs, int level, const char *buf, size_t len)
 {
 	char line[80];
-	int i, j;
+	unsigned int i, j;
 
 	for (i = 0; i < len; i += 16) {
 		int ofs;
@@ -265,10 +265,35 @@ const char *gg_debug_state(enum gg_state_t state)
 	GG_DEBUG_STATE(GG_STATE_CONNECTING_RELAY)
 	GG_DEBUG_STATE(GG_STATE_READING_RELAY)
 	GG_DEBUG_STATE(GG_STATE_DISCONNECTING)
+	GG_DEBUG_STATE(GG_STATE_CONNECT_HUB)
+	GG_DEBUG_STATE(GG_STATE_CONNECT_PROXY_HUB)
+	GG_DEBUG_STATE(GG_STATE_CONNECT_GG)
+	GG_DEBUG_STATE(GG_STATE_CONNECT_PROXY_GG)
+	GG_DEBUG_STATE(GG_STATE_CONNECTING_PROXY_HUB)
+	GG_DEBUG_STATE(GG_STATE_CONNECTING_PROXY_GG)
+	GG_DEBUG_STATE(GG_STATE_RESOLVE_HUB_SYNC)
+	GG_DEBUG_STATE(GG_STATE_RESOLVE_HUB_ASYNC)
+	GG_DEBUG_STATE(GG_STATE_RESOLVE_PROXY_HUB_SYNC)
+	GG_DEBUG_STATE(GG_STATE_RESOLVE_PROXY_HUB_ASYNC)
+	GG_DEBUG_STATE(GG_STATE_RESOLVE_PROXY_GG_SYNC)
+	GG_DEBUG_STATE(GG_STATE_RESOLVE_PROXY_GG_ASYNC)
+	GG_DEBUG_STATE(GG_STATE_RESOLVE_GG_SYNC)
+	GG_DEBUG_STATE(GG_STATE_RESOLVE_GG_ASYNC)
+	GG_DEBUG_STATE(GG_STATE_RESOLVING_HUB)
+	GG_DEBUG_STATE(GG_STATE_RESOLVING_PROXY_HUB)
+	GG_DEBUG_STATE(GG_STATE_RESOLVING_PROXY_GG)
+	GG_DEBUG_STATE(GG_STATE_SEND_HUB)
+	GG_DEBUG_STATE(GG_STATE_SEND_PROXY_HUB)
+	GG_DEBUG_STATE(GG_STATE_SEND_PROXY_GG)
+	GG_DEBUG_STATE(GG_STATE_SENDING_HUB)
+	GG_DEBUG_STATE(GG_STATE_SENDING_PROXY_HUB)
+	GG_DEBUG_STATE(GG_STATE_SENDING_PROXY_GG)
+	GG_DEBUG_STATE(GG_STATE_READING_HUB)
+	GG_DEBUG_STATE(GG_STATE_READING_PROXY_HUB)
+	GG_DEBUG_STATE(GG_STATE_READING_PROXY_GG)
 #undef GG_DEBUG_STATE
 
 	/* Celowo nie ma default, żeby kompilator wyłapał brakujące stany */
-	
 	}
 
 	return NULL;
@@ -323,6 +348,8 @@ const char *gg_debug_event(enum gg_event_t event)
 	GG_DEBUG_EVENT(GG_EVENT_DCC7_DONE)
 	GG_DEBUG_EVENT(GG_EVENT_DCC7_PENDING)
 	GG_DEBUG_EVENT(GG_EVENT_XML_EVENT)
+	GG_DEBUG_EVENT(GG_EVENT_JSON_EVENT)
+	GG_DEBUG_EVENT(GG_EVENT_ACK110)
 	GG_DEBUG_EVENT(GG_EVENT_DISCONNECT_ACK)
 	GG_DEBUG_EVENT(GG_EVENT_TYPING_NOTIFICATION)
 	GG_DEBUG_EVENT(GG_EVENT_USER_DATA)
@@ -330,10 +357,16 @@ const char *gg_debug_event(enum gg_event_t event)
 	GG_DEBUG_EVENT(GG_EVENT_MULTILOGON_INFO)
 	GG_DEBUG_EVENT(GG_EVENT_USERLIST100_VERSION)
 	GG_DEBUG_EVENT(GG_EVENT_USERLIST100_REPLY)
+	GG_DEBUG_EVENT(GG_EVENT_IMTOKEN)
+	GG_DEBUG_EVENT(GG_EVENT_PONG110)
+	GG_DEBUG_EVENT(GG_EVENT_CHAT_INFO)
+	GG_DEBUG_EVENT(GG_EVENT_CHAT_INFO_GOT_ALL)
+	GG_DEBUG_EVENT(GG_EVENT_CHAT_INFO_UPDATE)
+	GG_DEBUG_EVENT(GG_EVENT_CHAT_CREATED)
+	GG_DEBUG_EVENT(GG_EVENT_CHAT_INVITE_ACK)
 #undef GG_DEBUG_EVENT
 
 	/* Celowo nie ma default, żeby kompilator wyłapał brakujące zdarzenia */
-	
 	}
 
 	return NULL;
